@@ -19,4 +19,12 @@ population = [
      'x position': 330, 'y position': 38, 'max width': 254, 'max height': 57},
     {'Metadata': 'Organization logo', 'Frame': 'OS Engineer', 'Sheet': 'D',
      'x position': 19, 'y position': 38, 'max width': 191, 'max height': 25},
+
+    # D TRI MBSE
+    {'Metadata': 'Title', 'Frame': 'TRI MBSE', 'Sheet': 'D',
+     'x position': 19, 'y position': 584, 'max width': 254, 'max height': 25},
+    {'Metadata': 'Copyright notice', 'Frame': 'TRI MBSE', 'Sheet': 'D',
+     'x position': 400, 'y position': 38, 'max width': 254, 'max height': 57},
+    {'Metadata': 'Organization logo', 'Frame': 'TRI MBSE', 'Sheet': 'D',
+     'x position': 19, 'y position': 38, 'max width': 191, 'max height': 25},
 ]
